"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { changePassword } from "~/server/functions";
import { middleware } from "~/middleware";

type Data = {
  userId: number;
  oldPassword: string;
  newPassword: string;
};

export const POST = async (request: NextRequest) => {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const { userId, oldPassword, newPassword } = await request.json() as Data;
    console.log("Received request:", { userId, oldPassword, newPassword });

    console.log("Changing password for user:", userId);
    if (oldPassword === newPassword) {
      return NextResponse.json(
        { message: "New password cannot be the same as the old password" },
        { status: 400 }
      );
    }
    await changePassword(userId, oldPassword, newPassword);
    return NextResponse.json({ message: "Password changed successfully" });
  } catch (error) {
    console.error("Error in changePassword:", error);
    return NextResponse.json({ message: "Error changing password" }, { status: 500 });
  }
};
