"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { login } from "~/server/functions";
import { middleware } from "~/middleware";

type LoginRequest = {
  username: string;
  password: string;
}

export async function POST(request: NextRequest) {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const { username, password } = await request.json() as LoginRequest;
    console.log("Received request:", { username, password });

    if (!username || !password) {
      return NextResponse.json({ message: "Missing required fields" }, { status: 400 });
    }

    console.log("Logging in user:", username);
    const result = await login(username, password);

    if (result) {
      console.log("User logged in successfully");
      return NextResponse.json({ result }, { status: 200 });
    } else {
      throw new Error("Failed to log in user");
    }
  } catch (error) {
    console.error("Error in login:", error);
    if (error instanceof Error) {
      return NextResponse.json({ message: error.message }, { status: 400 });
    }
    return NextResponse.json({ message: "Error logging in user" }, { status: 500 });
  }
}
