"use server";
import { NextResponse } from "next/server";
import type { NextRequest } from "next/server";
import { refreshToken } from "~/server/functions";
import { middleware } from "~/middleware";

export async function POST(request: NextRequest) {
  const middlewareResponse = await middleware(request);
  if (middlewareResponse) return middlewareResponse;
  try {
    const { refreshToken: token } = await request.json() as { refreshToken: string };
    if (!token)
      return NextResponse.json({ message: "Refresh token is required" },{ status: 400 });
    const tokens = await refreshToken(token);
    return NextResponse.json(tokens);
  } catch (error) {
    if (error instanceof Error)
      return NextResponse.json({ message: error.message }, { status: 400 });
    else
      return NextResponse.json({ message: "Unknown error occurred" }, { status: 500 });
  }
}
