"use client";

import React, { useState } from 'react';

export default function CreateUserPage() {
  const [username, setUsername] = useState("");
  const [email, setEmail] = useState("");
  const [passwordHash, setPasswordHash] = useState("");
  const [name, setName] = useState("");
  const [pfpURL, setPfpURL] = useState("");
  const [pushToken, setPushToken] = useState("");
  const [result, setResult] = useState<string | null>(null);

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    setResult(null);

    try {
      const response = await fetch('/api/users/createUser', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
          'x-api-key': process.env.NEXT_PUBLIC_API_KEY ?? '',
        },
        body: JSON.stringify({
          username,
          email,
          passwordHash,
          name,
          pfpURL,
          pushToken
        })
      });
      const data = await response.json() as {message: string}
      setResult(JSON.stringify(data, null, 2));
    } catch (error) {
      console.error('Error:', error);
      setResult('An error occurred');
    }
  };

  return (
    <main className="flex min-h-screen flex-col items-center justify-center
      bg-gradient-to-b from-pink-500 to-orange-400 text-white cursor-pointer">
      <div className="p-4">
        <h1 className="text-2xl mb-4">Test Create User</h1>
        <form onSubmit={handleSubmit} className="space-y-4">
          <div>
            <label htmlFor="username" className="block">Username:</label>
            <input
              type="text"
              id="username"
              value={username}
              onChange={(e) => setUsername(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="email" className="block">Email:</label>
            <input
              type="text"
              id="email"
              value={email}
              onChange={(e) => setEmail(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="passwordHash" className="block">Password:</label>
            <input
              type="text"
              id="passwordHash"
              value={passwordHash}
              onChange={(e) => setPasswordHash(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="name" className="block">Name:</label>
            <input
              type="text"
              id="name"
              value={name}
              onChange={(e) => setName(e.target.value)}
              className="border p-2 w-full bg-black"
              required
            />
          </div>
          <div>
            <label htmlFor="pfpURL" className="block">Pfp URL:</label>
            <input
              type="text"
              id="pfpURL"
              value={pfpURL}
              onChange={(e) => setPfpURL(e.target.value)}
              className="border p-2 w-full bg-black"
            />
          </div>
          <div>
            <label htmlFor="pushToken" className="block">Push Token:</label>
            <input
              type="text"
              id="pushToken"
              value={pushToken}
              onChange={(e) => setPushToken(e.target.value)}
              className="border p-2 w-full bg-black"
            />
          </div>
          <button type='submit' className='bg-blue-500 p-2 rounded'>
            Create User
          </button>
        </form>
        {result && (
          <div className='mt-4 p-2 rounded bg-black'>
            <pre>{result}</pre>
          </div>
        )}
      </div>
    </main>
  );
};
